pub struct LoginDeviceRequest {
pub device_type: DeviceType,
pub device_identifier: String,
pub device_name: String,
pub device_push_token: Option<String>,
}Expand description
Device information for login requests. This is common across all login mechanisms and describes the device making the authentication request.
Fields
device_type: DeviceTypeThe type of device making the login request Note: today, we already have the DeviceType on the ApiConfigurations but we do not have the other device fields so we will accept the device data at login time for now. In the future, we might refactor the unauthN client to instantiate with full device info which would deprecate this struct. However, using the device_type here allows us to avoid any timing issues in scenarios where the device type could change between client instantiation and login (unlikely but possible).
device_identifier: StringUnique identifier for the device
device_name: StringHuman-readable name of the device
device_push_token: Option<String>Push notification token for the device (only for mobile devices)