pub struct TrustedDeviceUserDecryptionOption {
pub has_admin_approval: bool,
pub has_login_approving_device: bool,
pub has_manage_reset_password_permission: bool,
pub is_tde_offboarding: bool,
pub encrypted_private_key: Option<EncString>,
pub encrypted_user_key: Option<UnsignedSharedKey>,
}Expand description
SDK domain model for Trusted Device user decryption option.
Fields
has_admin_approval: boolWhether the user has admin approval for device login.
has_login_approving_device: boolWhether the user has a device that can approve logins.
has_manage_reset_password_permission: boolWhether the user has permission to manage password reset for other users.
is_tde_offboarding: boolWhether the user is in TDE offboarding.
encrypted_private_key: Option<EncString>The device key encrypted device private key. Only present if the device is trusted.
encrypted_user_key: Option<UnsignedSharedKey>The device private key encrypted user key. Only present if the device is trusted.