pub struct JitMasterPasswordRegistrationRequest {
pub org_id: OrganizationId,
pub org_public_key: B64,
pub organization_sso_identifier: String,
pub user_id: UserId,
pub salt: String,
pub master_password: String,
pub master_password_hint: Option<String>,
pub reset_password_enroll: bool,
}Expand description
Request parameters for SSO JIT master password registration.
Fields
org_id: OrganizationIdOrganization ID to enroll in
org_public_key: B64Organization’s public key for encrypting the reset password key. This should be verified by the client and not verifying may compromise the security of the user’s account.
organization_sso_identifier: StringOrganization SSO identifier
user_id: UserIdUser ID for the account being initialized
salt: StringSalt for master password hashing, usually email
master_password: StringMaster password for the account
master_password_hint: Option<String>Optional hint for the master password
reset_password_enroll: boolShould enroll user into admin password reset