pub struct KeyConnectorRegistrationResult {
pub account_cryptographic_state: WrappedAccountCryptographicState,
pub key_connector_key: B64,
pub key_connector_key_wrapped_user_key: EncString,
pub user_key: B64,
}Expand description
Result of Key Connector registration process.
Fields
account_cryptographic_state: WrappedAccountCryptographicStateThe account cryptographic state of the user.
key_connector_key: B64The key connector key used for unlocking.
key_connector_key_wrapped_user_key: EncStringThe encrypted user key, wrapped with the key connector key.
user_key: B64The decrypted user key. This can be used to get the consuming client to an unlocked state.