pub enum SendAccessTokenApiErrorResponse {
InvalidRequest {
error_description: Option<String>,
send_access_error_type: Option<SendAccessTokenInvalidRequestError>,
},
InvalidGrant {
error_description: Option<String>,
send_access_error_type: Option<SendAccessTokenInvalidGrantError>,
},
InvalidClient {
error_description: Option<String>,
},
UnauthorizedClient {
error_description: Option<String>,
},
UnsupportedGrantType {
error_description: Option<String>,
},
InvalidScope {
error_description: Option<String>,
},
InvalidTarget {
error_description: Option<String>,
},
}Expand description
Represents the possible, expected errors that can occur when requesting a send access token.
Variants
InvalidRequest
Invalid request error, typically due to missing parameters for a specific
credential flow. Ex. send_id is required.
Fields
send_access_error_type: Option<SendAccessTokenInvalidRequestError>The optional specific error type for invalid request errors.
InvalidGrant
Invalid grant error, typically due to invalid credentials.
Fields
send_access_error_type: Option<SendAccessTokenInvalidGrantError>The optional specific error type for invalid grant errors.
InvalidClient
Invalid client error, typically due to an invalid client secret or client ID.
Unauthorized client error, typically due to an unauthorized client.
Fields
The optional error description for unauthorized client errors.
UnsupportedGrantType
Unsupported grant type error, typically due to an unsupported credential flow. Note: during initial feature rollout, this will be used to indicate that the feature flag is disabled.
Fields
InvalidScope
Invalid scope error, typically due to an invalid scope requested.
InvalidTarget
Invalid target error which is shown if the requested resource is invalid, missing, unknown, or malformed.