pub struct SendAccessTokenRequest {
pub send_id: String,
pub send_access_credentials: Option<SendAccessCredentials>,
}Expand description
A request structure for requesting a send access token from the API.
Fields
send_id: StringThe id of the send for which the access token is requested.
send_access_credentials: Option<SendAccessCredentials>The optional send access credentials.