pub struct UnexpectedIdentityError(pub String);Expand description
Any unexpected error that occurs when making requests to identity. This could be
local/transport/decoding failure from the HTTP client (DNS/TLS/connect/read timeout,
connection reset, or JSON decode failure on a success response) or non-2xx response with an
unexpected body or status. Used when decoding the server’s error payload into
SendAccessTokenApiErrorResponse fails, or for 5xx responses where no structured error is
available.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for UnexpectedIdentityError
impl Debug for UnexpectedIdentityError
Sourceimpl<'de> Deserialize<'de> for UnexpectedIdentityError
impl<'de> Deserialize<'de> for UnexpectedIdentityError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UnexpectedIdentityError
impl PartialEq for UnexpectedIdentityError
Sourcefn eq(&self, other: &UnexpectedIdentityError) -> bool
fn eq(&self, other: &UnexpectedIdentityError) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UnexpectedIdentityError
impl Serialize for UnexpectedIdentityError
impl StructuralPartialEq for UnexpectedIdentityError